Django-cachalot
===============

Caches your Django ORM queries and automatically invalidates them.

.. image:: https://raw.github.com/BertrandBordage/django-cachalot/master/django-cachalot.jpg

----

.. image:: http://img.shields.io/pypi/v/django-cachalot.svg?style=flat-square
   :target: https://pypi.python.org/pypi/django-cachalot

.. image:: http://img.shields.io/travis/BertrandBordage/django-cachalot/master.svg?style=flat-square
   :target: https://travis-ci.org/BertrandBordage/django-cachalot

.. image:: http://img.shields.io/coveralls/BertrandBordage/django-cachalot/master.svg?style=flat-square
   :target: https://coveralls.io/r/BertrandBordage/django-cachalot?branch=master

.. image:: http://img.shields.io/scrutinizer/g/BertrandBordage/django-cachalot/master.svg?style=flat-square
   :target: https://scrutinizer-ci.com/g/BertrandBordage/django-cachalot/

.. image:: http://img.shields.io/gratipay/BertrandBordage.svg?style=flat-square
   :target: https://gratipay.com/BertrandBordage/

**Currently in beta, do not use in production**


Documentation
-------------

Available `on Read The Docs <http://django-cachalot.readthedocs.org>`_.
